@@ -3,6 +3,8 @@ use strict;
 use warnings;
 use version;
 
+our $VERSION = "1.001";
+
 sub new {
     my $class = shift;
 
@@ -12,53 +14,47 @@ sub new {
     return $self;
 }
 
+BEGIN {
+use version;
+my $ops = {
+	'<'  => sub { $_[0] <  0 },
+	'<=' => sub { $_[0] <= 0 },
+	'==' => sub { $_[0] == 0 },
+	'>'  => sub { $_[0] >  0 },
+	'>=' => sub { $_[0] >= 0 },
+	'!=' => sub { $_[0] != 0 },
+	};
+
 sub in_range {
-    my $self = shift;
-    my ( $version, $range ) = @_;
-
+    my( $self, $version, $range ) = @_;
+	my( @original ) = ($version, $range);
     return unless defined $version && defined $range;
-
     my @ands = split /\s*,\s*/, $range;
 
     return unless defined( $version = eval { version->parse($version) } );
 
+	my $result = 1;
+
     foreach my $and (@ands) {
-        my ( $op, $range_version ) = $and =~ m/^(<=|<|>=|>|==|!=)?\s*([^\s]+)$/;
+        my( $op, $range_version ) = $and =~ m/^(<=|<|>=|>|==|!=)?\s*([^\s]+)$/;
 
         return
           unless defined( $range_version = eval { version->parse($range_version) } );
 
         $op = '>=' unless defined $op;
+		unless( exists $ops->{$op} ) { $result = 0; last; }
 
-        if ( $op eq '<' ) {
-            return unless $version < $range_version;
-        }
-        elsif ( $op eq '<=' ) {
-            return unless $version <= $range_version;
-        }
-        elsif ( $op eq '>' ) {
-            return unless $version > $range_version;
-        }
-        elsif ( $op eq '>=' ) {
-            return unless $version >= $range_version;
-        }
-        elsif ( $op eq '==' ) {
-            return unless $version == $range_version;
-        }
-        elsif ( $op eq '!=' ) {
-            return unless $version != $range_version;
-        }
-        else {
-            return 0;
-        }
-    }
+		no warnings qw(numeric);
+		$result = $ops->{$op}->( version::vcmp($version, $range_version) );
+		last if $result == 0;
+		}
 
-    return 1;
+    return $result;
+	}
 }
 
 sub affected_versions {
-    my $self = shift;
-    my ( $available_versions, $range ) = @_;
+    my( $self, $available_versions, $range ) = @_;
 
     my @affected_versions;
     foreach my $version (@$available_versions) {
